@@ -52,7 +52,7 @@ const gchar *GKBD_KEYBOARD_CONFIG_ACTIVE[] = {
  */
 
 static gboolean
-g_strv_equal (gchar ** l1, gchar ** l2)
+gkbd_strv_equal (gchar ** l1, gchar ** l2)
 {
 	if (l1 == l2)
 		return TRUE;
@@ -555,7 +555,7 @@ gkbd_keyboard_config_equals (GkbdKeyboardConfig * kbd_config1,
 	    (kbd_config2->model != NULL) &&
 	    g_ascii_strcasecmp (kbd_config1->model, kbd_config2->model))
 		return False;
-	if (!g_strv_equal (kbd_config1->layouts_variants,
+	if (!gkbd_strv_equal (kbd_config1->layouts_variants,
 			   kbd_config2->layouts_variants))
 		return False;
 
@@ -705,10 +705,10 @@ gkbd_keyboard_config_to_string (const GkbdKeyboardConfig * config)
 			g_string_append (buffer, *iter);
 		}
 
-		/* Translators: The count is related to the number of options. The %s
-		 * format specifier should not be modified, left "as is". */
 		layouts =
 		    g_strdup_printf (ngettext
+				     /* Translators: The count is related to the number of options. The %s
+				     * format specifier should not be modified, left "as is". */
 				     ("layout \"%s\"", "layouts \"%s\"",
 				      count), buffer->str);
 		g_string_truncate (buffer, 0);
@@ -723,10 +723,10 @@ gkbd_keyboard_config_to_string (const GkbdKeyboardConfig * config)
 			g_string_append (buffer, *iter);
 		}
 
-		/* Translators: The count is related to the number of options. The %s
-		 * format specifier should not be modified, left "as is". */
 		options =
 		    g_strdup_printf (ngettext
+				     /* Translators: The count is related to the number of options. The %s
+				     * format specifier should not be modified, left "as is". */
 				     ("option \"%s\"", "options \"%s\"",
 				      count), buffer->str);
 		g_string_truncate (buffer, 0);
